This package is meant to be an exact mimic of `channels_redis` package, if you need a new feature, please open an issue there, and if accepted I'll add it here as well.

if you want to issue a bug report, please inform us of the following info:

- Your OS and runtime environment, and browser if applicable.
- the package's exact version.
- What you expect to happen vs. what actually happens.
- How you're running Channels (runserver? daphne/runworker? Nginx/Apache in front?).
- Console logs and full tracebacks of any errors
